# TencentAds\OauthApi

All URIs are relative to *https://sandbox-api.e.qq.com/v1.1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**oauthAuthorize**](OauthApi.md#oauthAuthorize) | **GET** /oauth/authorize | 获取Authorization Code
[**oauthToken**](OauthApi.md#oauthToken) | **GET** /oauth/token | 通过Authorization Code获取Access Token或刷新Access Token


# **oauthAuthorize**
> string oauthAuthorize($clientId, $redirectUri, $state, $scope, $accountType, $accountDisplayNumber)

获取Authorization Code

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

use TencentAds\TencentAds;

$tads = TencentAds::init([
            'access_token' => 'YOUR_ACCESS_TOKEN',
            'is_debug'     => true,
        ]);
$clientId = 789; // int | 应用 id，在开发者官网创建应用后获得，可通过 <a href='https://developers.e.qq.com/app' target='_blank'>[应用程序管理页面]</a> 查看
$redirectUri = "redirectUri_example"; // string | 应用回调地址，仅支持 http 和 https ，不支持指定端口号，且主域名必须与创建应用时登记的回调域名一致，若地址携带参数，需要对地址进行 urlencode
$state = "state_example"; // string | 验证请求有效性参数，值为用户自取，用于阻止跨站请求伪造攻击
$scope = "scope_example"; // string | 授权范围，可选值：ads_management（广告投放）、ads_insights（数据洞察）、account_management（帐号服务）、audience_management（人群管理）、user_actions（用户行为数据接入），不传即为授权全部权限
$accountType = "accountType_example"; // string | 授权账号类型
$accountDisplayNumber = 789; // int | 授权页面展示账号类型(QQ账号/微信账号)数量，当取值为1时授权页面仅展示account_type指定的账号类型，当取值为2时授权页面展示所有账号类型授权页面，默认优先显示account_type指定的账号类型

try {
    $result = $tads->oauth()->authorize($clientId, $redirectUri, $state, $scope, $accountType, $accountDisplayNumber);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling oauth()->authorize(): ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **clientId** | **int**| 应用 id，在开发者官网创建应用后获得，可通过 &lt;a href&#x3D;&#39;https://developers.e.qq.com/app&#39; target&#x3D;&#39;_blank&#39;&gt;[应用程序管理页面]&lt;/a&gt; 查看 |
 **redirectUri** | **string**| 应用回调地址，仅支持 http 和 https ，不支持指定端口号，且主域名必须与创建应用时登记的回调域名一致，若地址携带参数，需要对地址进行 urlencode |
 **state** | **string**| 验证请求有效性参数，值为用户自取，用于阻止跨站请求伪造攻击 | [optional]
 **scope** | **string**| 授权范围，可选值：ads_management（广告投放）、ads_insights（数据洞察）、account_management（帐号服务）、audience_management（人群管理）、user_actions（用户行为数据接入），不传即为授权全部权限 | [optional]
 **accountType** | **string**| 授权账号类型 | [optional]
 **accountDisplayNumber** | **int**| 授权页面展示账号类型(QQ账号/微信账号)数量，当取值为1时授权页面仅展示account_type指定的账号类型，当取值为2时授权页面展示所有账号类型授权页面，默认优先显示account_type指定的账号类型 | [optional]

### Return type

**string**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: text/plain
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **oauthToken**
> \TencentAds\Model\OauthTokenResponse oauthToken($clientId, $clientSecret, $grantType, $authorizationCode, $refreshToken, $redirectUri)

通过Authorization Code获取Access Token或刷新Access Token

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

use TencentAds\TencentAds;

$tads = TencentAds::init([
            'access_token' => 'YOUR_ACCESS_TOKEN',
            'is_debug'     => true,
        ]);
$clientId = 789; // int | 应用 id，在开发者官网创建应用后获得，可通过 <a href='https://developers.e.qq.com/app' target='_blank'>[应用程序管理页面]</a> 查看
$clientSecret = "clientSecret_example"; // string | 应用 secret，在开发者官网创建应用后获得，可通过 <a href='https://developers.e.qq.com/app' target='_blank'>[应用程序管理页面]</a> 查看
$grantType = "grantType_example"; // string | 请求的类型，可选值：authorization_code（授权码方式获取 token）、refresh_token（刷新 token）
$authorizationCode = "authorizationCode_example"; // string | OAuth 认证 code，可通过获取 Authorization Code 接口获取
$refreshToken = "refreshToken_example"; // string | 应用 refresh token，当 grant_type=refresh_token 时必填
$redirectUri = "redirectUri_example"; // string | 应用回调地址，仅支持 http 和 https ，不支持指定端口号，且主域名必须与创建应用时登记的回调域名一致，若地址携带参数，需要对地址进行 urlencode

try {
    $result = $tads->oauth()->token($clientId, $clientSecret, $grantType, $authorizationCode, $refreshToken, $redirectUri);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling oauth()->token(): ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **clientId** | **int**| 应用 id，在开发者官网创建应用后获得，可通过 &lt;a href&#x3D;&#39;https://developers.e.qq.com/app&#39; target&#x3D;&#39;_blank&#39;&gt;[应用程序管理页面]&lt;/a&gt; 查看 |
 **clientSecret** | **string**| 应用 secret，在开发者官网创建应用后获得，可通过 &lt;a href&#x3D;&#39;https://developers.e.qq.com/app&#39; target&#x3D;&#39;_blank&#39;&gt;[应用程序管理页面]&lt;/a&gt; 查看 |
 **grantType** | **string**| 请求的类型，可选值：authorization_code（授权码方式获取 token）、refresh_token（刷新 token） |
 **authorizationCode** | **string**| OAuth 认证 code，可通过获取 Authorization Code 接口获取 | [optional]
 **refreshToken** | **string**| 应用 refresh token，当 grant_type&#x3D;refresh_token 时必填 | [optional]
 **redirectUri** | **string**| 应用回调地址，仅支持 http 和 https ，不支持指定端口号，且主域名必须与创建应用时登记的回调域名一致，若地址携带参数，需要对地址进行 urlencode | [optional]

### Return type

[**\TencentAds\Model\OauthTokenResponse**](../Model/OauthTokenResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: text/plain
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

