<?php
require_once __DIR__ . '/../../../vendor/autoload.php'; // change path as needed
use TencentAds\TencentAds;
use TencentAds\Exception\TencentAdsResponseException;
use TencentAds\Exception\TencentAdsSDKException;

/*****
 * 本文件提供了一个修改推广计划(Campaign)的简单示例
 */
class UpdateCampaigns
{
    public static $tads;
    public static $ACCESS_TOKEN      = 'YOUR ACCESS TOKEN';
    public static $ACCOUNT_ID        = 'YOUR ACCOUNT ID';
    public static $CAMPAIGN_ID       = 'YOUR CAMPAIGN ID'; // 要修改的推广计划ID
    public static $DAILY_BUDGET      = 10000; // 日预算修改为100元(10000分)
    public static $CONFIGURED_STATUS = 'AD_STATUS_SUSPEND'; // 状态修改为暂停

    public function init()
    {
        $tads = TencentAds::init([
            'access_token' => static::$ACCESS_TOKEN,
            'is_debug'     => true,
        ]);
        $tads->useSandbox(); // 默认访问沙箱环境，如访问正式环境，请切换为$tads->useProduction()
        static::$tads = $tads;

        return $tads;
    }

    public function main()
    {
        try {
            /* @var TencentAds $tads */
            $tads = static::$tads;

            $response = $tads->campaigns()
                             ->update([
                                 'account_id'        => static::$ACCOUNT_ID,
                                 'campaign_id'       => static::$CAMPAIGN_ID,
                                 'daily_budget'      => static::$DAILY_BUDGET,
                                 'configured_status' => static::$CONFIGURED_STATUS,
                             ]);
            $campaignId = $response->getCampaignId();

            return $campaignId;
        } catch (TencentAdsResponseException $e) {
            // When Api returns an error
            echo 'Tencent ads returned an error: ' . $e->getMessage() . PHP_EOL;
            throw $e;
        } catch (TencentAdsSDKException $e) {
            // When validation fails or other local issues
            echo 'Tencent ads SDK returned an error: ' . $e->getMessage() . PHP_EOL;
            throw $e;
        } catch (Exception $e) {
            echo 'Other exception: ' . $e->getMessage() . PHP_EOL;
            throw $e;
        }
    }
}

if (basename($_SERVER['PHP_SELF']) == basename(__FILE__)) {
    try {
        $example = new UpdateCampaigns();
        $example->init();
        $example->main();
    } catch (\Exception $e) {
        exit(-1);
    }
}
