<?php
namespace TencentAds\Container;

use GuzzleHttp\Client;
use TencentAds\Api\PlayablePagesApi;
use TencentAds\Kernel\ApiContainer;
use TencentAds\Kernel\HeaderHandler;
use TencentAds\Middleware\Model\MiddlewareRequest;
use TencentAds\TencentAds;

class PlayablePagesApiContainer extends ApiContainer
{
    /** @var PlayablePagesApi */
    public $apiInstance;


    /**
     * @param TencentAds $app
     * @param Client $client
     * @return PlayablePagesApiContainer
     */
    public function init(TencentAds $app, Client $client)
    {
        parent::init($app, $client);
        $this->apiInstance = new PlayablePagesApi($client, $app->getConfig(), new HeaderHandler());
        return $this;
    }


    /**
     * Handle PlayablePagesApi playablePagesAdd function
     * @param array params
     * @return \TencentAds\Model\PlayablePageAddResponseData
     * @throws \TencentAds\ApiException
     * @throws \TencentAds\Exception\TencentAdsResponseException
     */
    public function add(array $params = [])
    {
        return $this->handleMiddleware('add', $params, function(MiddlewareRequest $request) {
            $params = $request->getApiMethodArguments();
            $accountId = isset($params['account_id']) ? $params['account_id'] : null;
            $playablePageName = isset($params['playable_page_name']) ? $params['playable_page_name'] : null;
            $materialFile = isset($params['material_file']) ? $params['material_file'] : null;
            $response = $this->apiInstance->playablePagesAdd($accountId, $playablePageName, $materialFile);
            return $this->handleResponse($response);
        });
    }


    /**
     * Handle PlayablePagesApi playablePagesAddAsync function
     * @param array params
     * @return \GuzzleHttp\Promise\PromiseInterface
     */
    public function addAsync(array $params = [])
    {
        return $this->handleMiddleware('add', $params, function(MiddlewareRequest $request) {
            $params = $request->getApiMethodArguments();
            $accountId = isset($params['account_id']) ? $params['account_id'] : null;
            $playablePageName = isset($params['playable_page_name']) ? $params['playable_page_name'] : null;
            $materialFile = isset($params['material_file']) ? $params['material_file'] : null;
            $response = $this->apiInstance->playablePagesAddAsync($accountId, $playablePageName, $materialFile);
            return $response;
        });
    }


    /**
     * Handle PlayablePagesApi playablePagesGet function
     * @param array params
     * @return \TencentAds\Model\PlayablePageListData
     * @throws \TencentAds\ApiException
     * @throws \TencentAds\Exception\TencentAdsResponseException
     */
    public function get(array $params = [])
    {
        return $this->handleMiddleware('get', $params, function(MiddlewareRequest $request) {
            $params = $request->getApiMethodArguments();
            $accountId = isset($params['account_id']) ? $params['account_id'] : null;
            $filtering = isset($params['filtering']) ? $params['filtering'] : null;
            $page = isset($params['page']) ? $params['page'] : null;
            $pageSize = isset($params['page_size']) ? $params['page_size'] : null;
            $fields = isset($params['fields']) ? $params['fields'] : null;
            $response = $this->apiInstance->playablePagesGet($accountId, $filtering, $page, $pageSize, $fields);
            return $this->handleResponse($response);
        });
    }


    /**
     * Handle PlayablePagesApi playablePagesGetAsync function
     * @param array params
     * @return \GuzzleHttp\Promise\PromiseInterface
     */
    public function getAsync(array $params = [])
    {
        return $this->handleMiddleware('get', $params, function(MiddlewareRequest $request) {
            $params = $request->getApiMethodArguments();
            $accountId = isset($params['account_id']) ? $params['account_id'] : null;
            $filtering = isset($params['filtering']) ? $params['filtering'] : null;
            $page = isset($params['page']) ? $params['page'] : null;
            $pageSize = isset($params['page_size']) ? $params['page_size'] : null;
            $fields = isset($params['fields']) ? $params['fields'] : null;
            $response = $this->apiInstance->playablePagesGetAsync($accountId, $filtering, $page, $pageSize, $fields);
            return $response;
        });
    }
}
